pub struct ApiClient { /* private fields */ }

Implementations

Api client for demos.tf

Example

use demostf_client::{ListOrder, ListParams, ApiClient};

let client = ApiClient::new();

let demos = client.list(ListParams::default().with_order(ListOrder::Ascending), 1).await?;

for demo in demos {
    println!("{}: {}", demo.id, demo.name);
}

Create an api client for the default demos.tf endpoint

Create an api client using a different api endpoint

List demos with the provided options

note that the pages start counting at 1

Example
use demostf_client::{ListOrder, ListParams};

let demos = client.list(ListParams::default().with_order(ListOrder::Ascending), 1).await?;

for demo in demos {
    println!("{}: {}", demo.id, demo.name);
}

List demos uploaded by a user with the provided options

note that the pages start counting at 1

Example
use demostf_client::{ListOrder, ListParams};

let client = ApiClient::default();
let demos = client.list_uploads(SteamID::from(76561198024494988), ListParams::default().with_order(ListOrder::Ascending), 1).await?;

for demo in demos {
    println!("{}: {}", demo.id, demo.name);
}

Get the data for a single demo

Example
let demo = client.get(9).await?;

println!("{}: {}", demo.id, demo.name);
println!("players:");

for player in demo.players {
    println!("{}", player.user.name);
}

Get user info by id

Example
let user = client.get_user(1).await?;

println!("{} ({})", user.name, user.steam_id.steam3());

List demos with the provided options

Example
let chat = client.get_chat(447678).await?;

for message in chat {
    println!("{}: {}", message.user, message.message);
}