Struct demostf_client::Demo
source · [−]pub struct Demo {Show 18 fields
pub id: u32,
pub url: String,
pub name: String,
pub server: String,
pub duration: u16,
pub nick: String,
pub map: String,
pub time: OffsetDateTime,
pub red: String,
pub blue: String,
pub red_score: u8,
pub blue_score: u8,
pub player_count: u8,
pub uploader: UserRef,
pub hash: [u8; 16],
pub backend: String,
pub path: String,
pub players: Option<Vec<Player>>,
}Expand description
Data of an uploaded demo
Fields
id: u32url: Stringname: Stringserver: Stringduration: u16nick: Stringmap: Stringtime: OffsetDateTimered: Stringblue: Stringred_score: u8blue_score: u8player_count: u8uploader: UserRefhash: [u8; 16]backend: Stringpath: Stringplayers: Option<Vec<Player>>Demos listed using ApiClient::list will not have any players set, use get_players to automatically
load the players when not set
Implementations
sourceimpl Demo
impl Demo
sourcepub async fn get_players(
&self,
client: &ApiClient
) -> Result<Cow<'_, [Player]>, Error>
pub async fn get_players(
&self,
client: &ApiClient
) -> Result<Cow<'_, [Player]>, Error>
Return either the stored players info or get the players from the api