Struct demostf_client::Player
source · [−]pub struct Player {
pub player_id: u32,
pub user: User,
pub team: Team,
pub class: Class,
pub kills: u8,
pub assists: u8,
pub deaths: u8,
}Expand description
Data of a player in a demo
Fields
player_id: u32user: Userteam: Teamclass: ClassIf a player has played multiple classes, the class which the user spawned the most as is taken
kills: u8assists: u8deaths: u8Trait Implementations
sourceimpl<'de> Deserialize<'de> for Player
impl<'de> Deserialize<'de> for Player
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more